@@ -128,6 +128,16 @@ namespace MonoDevelop.Debugger.Gdb
 			return values.ToArray ();
 		}
 		
+		public ExceptionInfo GetException (int frameIndex, EvaluationOptions options)
+		{
+			return null;
+		}
+		
+		public ValidationResult ValidateExpression (int frameIndex, string expression, EvaluationOptions options)
+		{
+			return new ValidationResult (true, null);
+		}
+		
 		public CompletionData GetExpressionCompletionData (int frameIndex, string exp)
 		{
 			SelectFrame (frameIndex);
@@ -216,6 +226,10 @@ namespace MonoDevelop.Debugger.Gdb
 			ObjectValue val;
 			ObjectValueFlags flags = ObjectValueFlags.Variable;
 			
+			// There can be 'public' et al children for C++ structures
+			if (typeName == null)
+				typeName = "none";
+			
 			if (typeName.EndsWith ("]")) {
 				val = ObjectValue.CreateArray (this, new ObjectPath (vname), typeName, nchild, flags, null);
 			} else if (value == "{...}" || typeName.EndsWith ("*") || nchild > 0) {
@@ -227,12 +241,17 @@ namespace MonoDevelop.Debugger.Gdb
 			return val;
 		}
 
-		public ObjectValue[] GetChildren (ObjectPath path, int index, int count)
+		public ObjectValue[] GetChildren (ObjectPath path, int index, int count, EvaluationOptions options)
 		{
 			List<ObjectValue> children = new List<ObjectValue> ();
 			session.SelectThread (threadId);
 			GdbCommandResult res = session.RunCommand ("-var-list-children", "2", path.Join ("."));
 			ResultData cdata = res.GetObject ("children");
+			
+			// The response may not contain the "children" list at all.
+			if (cdata == null)
+				return children.ToArray ();
+			
 			if (index == -1) {
 				index = 0;
 				count = cdata.Count;
@@ -246,13 +265,21 @@ namespace MonoDevelop.Debugger.Gdb
 				if (name.Length > 0 && char.IsNumber (name [0]))
 					name = "[" + name + "]";
 				
-				ObjectValue val = CreateObjectValue (name, child);
-				children.Add (val);
+				// C++ structures may contain typeless children named
+				// "public", "private" and "protected".
+				if (child.GetValue("type") == null) {
+					ObjectPath childPath = new ObjectPath (child.GetValue ("name").Split ('.'));
+					ObjectValue[] subchildren = GetChildren (childPath, -1, -1, options);
+					children.AddRange(subchildren);
+				} else {
+					ObjectValue val = CreateObjectValue (name, child);
+					children.Add (val);
+				}
 			}
 			return children.ToArray ();
 		}
 		
-		public EvaluationResult SetValue (ObjectPath path, string value)
+		public EvaluationResult SetValue (ObjectPath path, string value, EvaluationOptions options)
 		{
 			session.SelectThread (threadId);
 			session.RunCommand ("-var-assign", path.Join ("."), value);
@@ -332,6 +359,15 @@ namespace MonoDevelop.Debugger.Gdb
 			
 			return buffer.GetLines (firstLine, firstLine + count - 1);
 		}
+		
+		public object GetRawValue (ObjectPath path, EvaluationOptions options)
+		{
+			return null;
+		}
+		
+		public void SetRawValue (ObjectPath path, object value, EvaluationOptions options)
+		{
+		}
 	}
 	
 	class GdbDissassemblyBuffer: DissassemblyBuffer
