@@ -48,7 +48,7 @@ namespace MonoDevelop.Debugger.Gdb
 		Process proc;
 		StreamReader sout;
 		StreamWriter sin;
-		ProcessWrapper console;
+		IProcessAsyncOperation console;
 		GdbCommandResult lastResult;
 		bool running;
 		Thread thread;
@@ -88,7 +88,7 @@ namespace MonoDevelop.Debugger.Gdb
 					DateTime tim = DateTime.Now;
 					while (!File.Exists (ttyfileDone)) {
 						System.Threading.Thread.Sleep (100);
-						if ((DateTime.Now - tim).TotalSeconds > 4)
+						if ((DateTime.Now - tim).TotalSeconds > 10)
 							throw new InvalidOperationException ("Console could not be created.");
 					}
 					tty = File.ReadAllText (ttyfile).Trim (' ','\n');
@@ -175,14 +175,15 @@ namespace MonoDevelop.Debugger.Gdb
 			sin = proc.StandardInput;
 			
 			thread = new Thread (OutputInterpreter);
+			thread.Name = "GDB output interpeter";
 			thread.IsBackground = true;
 			thread.Start ();
 		}
 		
 		public override void Dispose ()
 		{
-			if (console != null && !console.HasExited) {
-				console.Kill ();
+			if (console != null && !console.IsCompleted) {
+				console.Cancel ();
 				console = null;
 			}
 				
@@ -322,7 +323,6 @@ namespace MonoDevelop.Debugger.Gdb
 			if (bp.HitAction == HitAction.PrintExpression) {
 				GdbCommandResult res = RunCommand ("-data-evaluate-expression", Escape (bp.TraceExpression));
 				string val = res.GetValue ("value");
-				OnDebuggerOutput (false, val + "\n");
 				NotifyBreakEventUpdate (handle, 0, val);
 				return false;
 			}
